@@ -1,6 +1,5 @@
 import chevron
 from requests import JSONDecodeError
-from urllib.parse import urljoin
 from .authenticate import Authenticate
 from .attachments import parse_attachment_output
 
@@ -12,7 +11,7 @@ class Runner(Authenticate):
             return self.parse_response(self.auth_error_response, action_schema)
         response = self.session.request(
             method=self.get_method(inputs, action_schema['meta']),
-            url=urljoin(self.url, self.get_endpoint(inputs, action_schema['meta'])),
+            url=self._join_url(self.url, self.get_endpoint(inputs, action_schema['meta'])),
             **self.get_kwargs(inputs, action_schema['meta'])
         )
         resp = self.parse_response(response, action_schema)
